@@ -37,16 +37,15 @@ class WorkflowTemplateService:
         host: Optional[str] = None,
         verify_ssl: bool = True,
         token: Optional[str] = None,
-        namespace: str = 'default',
+        namespace: str = "default",
     ):
-        self._host = host
-        self._verify_ssl = verify_ssl
         self._namespace = namespace
-        api_client = Client(Config(host=self._host, verify_ssl=self._verify_ssl), token=token).api_client
+        self._config = Config(host=host, verify_ssl=verify_ssl)
+        api_client = Client(self._config, token=token).api_client
         self.service = WorkflowTemplateServiceApi(api_client=api_client)
 
     def create(
-        self, workflow_template: IoArgoprojWorkflowV1alpha1WorkflowTemplate, namespace: str = 'default'
+        self, workflow_template: IoArgoprojWorkflowV1alpha1WorkflowTemplate, namespace: str = "default"
     ) -> IoArgoprojWorkflowV1alpha1WorkflowTemplate:
         """Creates given workflowTemplate in the argo server.
 
@@ -72,7 +71,7 @@ class WorkflowTemplateService:
             _check_return_type=False,
         )
 
-    def delete(self, name: str, namespace: str = 'default') -> Tuple[object, int, dict]:
+    def delete(self, name: str, namespace: str = "default") -> Tuple[object, int, dict]:
         """Deletes a workflow template from the given namespace based on the specified name.
 
         Parameters
